Method: Grit::Repo#tree

Defined in:
lib/grit/repo.rb

#tree(treeish = 'master', paths = []) ⇒ Object

The Tree object for the given treeish reference treeish is the reference (default 'master') paths is an optional Array of directory paths to restrict the tree (default [])

Examples repo.tree('master', ['lib/'])

Returns Grit::Tree (baked)



503
504
505
# File 'lib/grit/repo.rb', line 503

def tree(treeish = 'master', paths = [])
  Tree.construct(self, treeish, paths)
end